@@ -23,7 +23,6 @@ except ImportError:
     )
 
 
-global _THEMES_PATH
 _THEMES_PATH = os.path.join(
     os.path.dirname(os.path.abspath(pelican.__file__)), "themes"
 )
@@ -240,19 +239,16 @@ def install(path, v=False, u=False):
                 except OSError as e:
                     err(
                         "Cannot change permissions of files "
-                        "or directory in `{r}':\n{e}".format(r=theme_path, e=str(e)),
+                        f"or directory in `{theme_path}':\n{e!s}",
                         die=False,
                     )
             except Exception as e:
-                err(
-                    "Cannot copy `{p}' to `{t}':\n{e}".format(
-                        p=path, t=theme_path, e=str(e)
-                    )
-                )
+                err(f"Cannot copy `{path}' to `{theme_path}':\n{e!s}")
 
 
 def symlink(path, v=False):
     """Symbolically link a theme"""
+    path = os.path.realpath(path)
     if not os.path.exists(path):
         err(path + " : no such file or directory")
     elif not os.path.isdir(path):
@@ -268,16 +264,12 @@ def symlink(path, v=False):
             try:
                 os.symlink(path, theme_path)
             except Exception as e:
-                err(
-                    "Cannot link `{p}' to `{t}':\n{e}".format(
-                        p=path, t=theme_path, e=str(e)
-                    )
-                )
+                err(f"Cannot link `{path}' to `{theme_path}':\n{e!s}")
 
 
 def is_broken_link(path):
     """Returns True if the path given as is a broken symlink"""
-    path = os.readlink(path)
+    path = os.path.realpath(path)
     return not os.path.exists(path)
 
 
